@@ -17,7 +17,7 @@ dt_col_merge_add <- function(data, col_merge) {
   dt_col_merge_set(data = data, col_merge = added)
 }
 
-dt_col_merge_entry <- function(vars, type, pattern = NULL, ...) {
+dt_col_merge_entry <- function(vars, rows, type, pattern = NULL, ...) {
 
   if (!(type %in% c("merge", "merge_range", "merge_uncert", "merge_n_pct"))) {
     cli::cli_abort("Invalid `type` provided.")
@@ -25,6 +25,7 @@ dt_col_merge_entry <- function(vars, type, pattern = NULL, ...) {
 
   list(
     vars = vars,
+    rows = rows,
     type = type,
     pattern = pattern,
     ...
