@@ -24,10 +24,8 @@ dt_data_init <- function(data, data_tbl, rownames_to_column = NA) {
       ))
     }
 
-    data_tbl <-
-      data_tbl %>%
-      dplyr::mutate(!!sym(rownames_to_column) := data_rownames) %>%
-      dplyr::select(!!sym(rownames_to_column), dplyr::everything())
+    data_tbl <- dplyr::mutate(data_tbl, !!sym(rownames_to_column) := data_rownames)
+    data_tbl <- dplyr::select(data_tbl, !!sym(rownames_to_column), dplyr::everything())
   }
 
   dt_data_set(data = data, data_tbl = data_tbl)
