@@ -1,12 +1,10 @@
 .dt_row_groups_key <- "_row_groups"
 
 dt_row_groups_get <- function(data) {
-
   dt__get(data, .dt_row_groups_key)
 }
 
 dt_row_groups_set <- function(data, row_groups) {
-
   dt__set(data, .dt_row_groups_key, row_groups)
 }
 
@@ -20,9 +18,5 @@ dt_row_groups_init <- function(data) {
     row_groups <- character(0)
   }
 
-  data <-
-    row_groups %>%
-    dt_row_groups_set(data = data)
-
-  data
+  dt_row_groups_set(data = data, row_groups = row_groups)
 }
