@@ -28,6 +28,24 @@ filter_table_to_value <- function(
   dplyr::pull(filtered_tbl, !!column_enquo)
 }
 
+normalize_locale <- function(locale = NULL) {
+
+  # Return NULL if the locale isn't specified
+  if (is.null(locale)) {
+    return(NULL)
+  }
+
+  # Normalize any underscores to hyphens
+  locale <- gsub("_", "-", locale)
+
+  # Resolve any default locales into their base names (e.g., 'en-US' -> 'en')
+  if (locale %in% default_locales$default_locale) {
+    locale <- default_locales[default_locales$default_locale == locale, ][["base_locale"]]
+  }
+
+  locale
+}
+
 #' Validate the user-supplied `locale` value
 #'
 #' @param locale The user-supplied `locale` value, found in several `fmt_*()`
@@ -37,7 +55,11 @@ validate_locale <- function(locale) {
 
   # Stop function if the `locale` provided
   # isn't a valid one
-  if (!is.null(locale) && !(locale %in% locales$base_locale_id)) {
+  if (
+    !is.null(locale) &&
+    !(gsub("_", "-", locale) %in% locales[["locale"]]) &&
+    !(gsub("_", "-", locale) %in% default_locales[["default_locale"]])
+  ) {
 
     cli::cli_abort(c(
       "The supplied `locale` is not available in the list of supported locales.",
@@ -90,27 +112,22 @@ get_locale_sep_mark <- function(
     use_seps
 ) {
 
-  # If `use_seps` is FALSE, then force
-  # `sep_mark` to be an empty string
+  # If `use_seps` is FALSE, then force `sep_mark` to be an empty string
   if (!use_seps) {
     return("")
   }
 
-  # If `locale` is NULL then return the
-  # default `sep_mark`
+  # If `locale` is NULL then return the default `sep_mark`
   if (is.null(locale)) {
     return(default)
   }
 
-  # Get the correct `group_sep` value from the
-  # `gt:::locales` lookup table
-  sep_mark <-
-    filter_table_to_value(locales, group_sep, base_locale_id == locale)
+  # Get the correct `group_sep` value from the `gt:::locales` lookup table
+  sep_mark <- filter_table_to_value(locales, group, locale == {{ locale }})
 
-  # TODO: Modify `locales` table to replace `""` with
-  # `" "` in `group_sep` column; once that is done, the
-  # below statement can be safely removed
-  if (sep_mark == "") sep_mark <- " "
+  # Replace any `""` or "\u00a0" with `" "` since an empty string actually
+  # signifies a space character, and, we want to normalize to a simple space
+  if (sep_mark == "" || sep_mark == "\u00a0") sep_mark <- " "
 
   sep_mark
 }
@@ -123,15 +140,81 @@ get_locale_sep_mark <- function(
 #' @noRd
 get_locale_dec_mark <- function(locale = NULL, default) {
 
-  # If `locale` is NULL then return the
-  # default `dec_mark`
+  # If `locale` is NULL then return the default `dec_mark`
   if (is.null(locale)) {
     return(default)
   }
 
-  # Get the correct `dec_sep` value from the
-  # `gt:::locales` lookup table
-  filter_table_to_value(locales, dec_sep, base_locale_id == locale)
+  # Get the correct `decimal` value from the `gt:::locales` lookup table
+  filter_table_to_value(locales, decimal, locale == {{ locale }})
+}
+
+#' Get the `idx_set` vector based on a locale
+#'
+#' @param locale The user-supplied `locale` value, found in several `fmt_*()`
+#'   functions. This is expected as `NULL` if not supplied by the user.
+#' @noRd
+get_locale_idx_set <- function(locale = NULL) {
+
+  # If `locale` is NULL then return `LETTERS`
+  if (is.null(locale)) {
+    return(LETTERS)
+  }
+
+  locales[locales$locale == locale, ][["chr_index"]][[1]]
+}
+
+#' Get the `idx_num_spellout` vector based on a locale
+#'
+#' @param locale The user-supplied `locale` value, found in several `fmt_*()`
+#'   functions. This is expected as `NULL` if not supplied by the user.
+#' @noRd
+get_locale_num_spellout <- function(locale = NULL) {
+
+  # If `locale` is NULL then set locale as 'en'
+  if (is.null(locale)) {
+    locale <- "en"
+  }
+
+  # Get a vector of all locales from the column names of the
+  # `spelled_num` dataset
+  all_locales <- base::setdiff(names(spelled_num), "number")
+
+  # The user may supply a valid locale (even one from those available
+  # in `gt:::locales`) but there is no associated locale in `all_locales`;
+  # in such a case when strip it down to the language and check if it is
+  # then available in this internal dataset
+  if (!(locale %in% all_locales)) {
+
+    locale_segments <- get_locale_segments(locale = locale)
+
+    if (any(locale_segments %in% all_locales)) {
+
+      locale <- locale_segments[locale_segments %in% all_locales]
+
+    } else {
+      locale <- "en"
+    }
+  }
+
+  spelled_num[[locale]]
+}
+
+get_locale_segments <- function(locale) {
+
+  if (!grepl("-", locale)) {
+    return(locale)
+  }
+
+  segments <- locale
+
+  while (grepl("-", locale)) {
+
+    locale <- gsub("-[^-]*$", "", locale)
+    segments <- c(segments, locale)
+  }
+
+  segments
 }
 
 #' Resolve the locale in functions with a `locale` argument
@@ -152,6 +235,8 @@ resolve_locale <- function(data, locale) {
     locale <- dt_locale_get_value(data = data)
   }
 
+  locale <- normalize_locale(locale = locale)
+
   validate_locale(locale = locale)
 
   locale
@@ -633,6 +718,40 @@ context_exp_marks <- function(context) {
   )
 }
 
+#' Obtain the contextually correct string for scientific or engineering notation
+#' where the default style (`"x10n"`) is not used.
+#'
+#' @param context The output context.
+#' @param exp_style The style of formatting to use for the exponential notation.
+#' @noRd
+context_exp_str <- function(context, exp_style) {
+
+  # Set default value for `exp_str`
+  exp_str <- "E"
+
+  # For the 'low-ten' style, a different `exp_str` value will be obtained
+  # depending on the `context`
+  if (exp_style == "low-ten") {
+
+    exp_str <-
+      switch(
+        context,
+        html = c("<sub style='font-size: 65%;'>10</sub>"),
+        latex = c("{}_10"),
+        rtf = c("{\\sub 10}"),
+        word = c("10^"),
+        "E"
+      )
+  }
+
+  # If there is a single letter (or a letter and a '1') then
+  # used that letter as the `exp_str` value
+  if (grepl("^[a-zA-Z]{1}1?$", exp_style)) {
+    exp_str <- substr(exp_style, 1, 1)
+  }
+
+  exp_str
+}
 
 #' Obtain the contextually correct symbol string
 #'
@@ -674,7 +793,8 @@ context_symbol_str <- function(context, symbol) {
         if (!inherits(symbol, "AsIs")) {
           paste_between(
             markdown_to_latex(
-              get_currency_str(currency = symbol, fallback_to_code = TRUE)
+              get_currency_str(currency = symbol, fallback_to_code = TRUE),
+              md_engine = "commonmark"
             ),
             c("\\text{", "}")
           )
