@@ -1,12 +1,24 @@
 #' Transform a footnote mark to an HTML representation
 #'
 #' @noRd
-footnote_mark_to_html <- function(mark) {
+footnote_mark_to_html <- function(
+    data,
+    mark,
+    location = c("ref", "ftr")
+) {
+
+  location <- match.arg(location)
 
   if (is.na(mark)) {
     return("")
   }
 
+  spec <- get_footnote_spec_by_location(data = data, location = location)
+
+  if (is.null(spec)) {
+    spec <- "^i"
+  }
+
   # Generate the CSS classes needed on the basis of whether the
   # mark is one or more asterisk characters or anything else
   if (!grepl("^[\\*]+?$", mark)) {
@@ -15,7 +27,130 @@ footnote_mark_to_html <- function(mark) {
     sup_class <- "gt_footnote_marks gt_asterisk"
   }
 
-  as.character(htmltools::tags$sup(class = sup_class, mark))
+  is_sup <- grepl("\\^", spec)
+
+  if (grepl("\\.", spec)) mark <- paste0(mark, ".")
+  if (grepl("\\(", spec)) mark <- paste0("(", mark)
+  if (grepl("\\[", spec)) mark <- paste0("[", mark)
+  if (grepl("\\)", spec)) mark <- paste0(mark, ")")
+  if (grepl("\\]", spec)) mark <- paste0(mark, "]")
+
+  if (grepl("i", spec)) {
+    font_style <- "italic"
+  } else {
+    font_style <- "normal"
+  }
+
+  if (grepl("b", spec)) {
+    font_weight <- "bold"
+  } else {
+    font_weight <- "normal"
+  }
+
+  paste0(
+    "<span ",
+    if (is_sup) {
+      paste0("class=\"", sup_class, "\" ")
+    } else {
+      NULL
+    },
+    "style=\"",
+    "white-space:nowrap;",
+    "font-style:", font_style, ";",
+    "font-weight:", font_weight, ";",
+    "\">",
+    if (is_sup) {
+      paste0("<sup>", mark, "</sup>")
+    } else {
+      mark
+    },
+    "</span>"
+  )
+}
+
+get_font_stack <- function(
+    name = c(
+      "system-ui", "transitional", "old-style", "humanist",
+      "geometric-humanist", "classical-humanist", "neo-grotesque",
+      "monospace-slab-serif", "monospace-code", "industrial",
+      "rounded-sans", "slab-serif", "antique", "didone", "handwritten"
+    ),
+    add_emoji = TRUE
+) {
+
+  name <- match.arg(name)
+
+  font_stack <-
+    switch(
+      name,
+      "system-ui" = c(
+        "system-ui", "Segoe UI", "Roboto", "Helvetica", "Arial", "sans-serif"
+      ),
+      "transitional" = c(
+        "Charter", "Bitstream Charter", "Sitka Text", "Cambria", "serif"
+      ),
+      "old-style" = c(
+        "Iowan Old Style", "Palatino Linotype", "URW Palladio L", "P052", "serif"
+      ),
+      "humanist" = c(
+        "Seravek", "Gill Sans Nova", "Ubuntu", "Calibri", "DejaVu Sans",
+        "source-sans-pro", "sans-serif"
+      ),
+      "geometric-humanist" = c(
+        "Avenir", "Avenir Next LT Pro", "Montserrat", "Corbel", "URW Gothic",
+        "source-sans-pro", "sans-serif"
+      ),
+      "classical-humanist" = c(
+        "Optima", "Candara", "Noto Sans", "source-sans-pro", "sans-serif"
+      ),
+      "neo-grotesque" = c(
+        "Inter", "Roboto", "Helvetica Neue", "Arial Nova", "Nimbus Sans",
+        "Arial", "sans-serif"
+      ),
+      "monospace-slab-serif" = c(
+        "Nimbus Mono PS", "Courier New", "Cutive Mono", "monospace"
+      ),
+      "monospace-code" = c(
+        "ui-monospace", "Cascadia Code", "Source Code Pro", "Menlo", "Consolas",
+        "DejaVu Sans Mono", "monospace"
+      ),
+      "industrial" = c(
+        "Bahnschrift", "DIN Alternate", "Franklin Gothic Medium",
+        "Nimbus Sans Narrow", "sans-serif-condensed", "sans-serif"
+      ),
+      "rounded-sans" = c(
+        "ui-rounded", "Hiragino Maru Gothic ProN", "Quicksand", "Comfortaa",
+        "Manjari", "Arial Rounded MT Bold", "Calibri", "source-sans-pro",
+        "sans-serif"
+      ),
+      "slab-serif" = c(
+        "Rockwell", "Rockwell Nova", "Roboto Slab", "DejaVu Serif",
+        "Sitka Small", "serif"
+      ),
+      "antique" = c(
+        "Superclarendon", "Bookman Old Style", "URW Bookman", "URW Bookman L",
+        "Georgia Pro", "Georgia", "serif"
+      ),
+      "didone" = c(
+        "Didot", "Bodoni MT", "Noto Serif Display", "URW Palladio L", "P052",
+        "Sylfaen", "serif"
+      ),
+      "handwritten" = c(
+        "Segoe Print", "Bradley Hand", "Chilanka", "TSCu_Comic",
+        "casual", "cursive"
+      )
+    )
+
+  if (add_emoji) {
+    font_stack <-
+      c(
+        font_stack,
+        "Apple Color Emoji", "Segoe UI Emoji",
+        "Segoe UI Symbol", "Noto Color Emoji"
+      )
+  }
+
+  font_stack
 }
 
 styles_to_html <- function(styles) {
@@ -55,6 +190,7 @@ cell_style_to_html.default <- function(style) {
 
 # Upgrade `_styles` to gain a `html_style` column with CSS style rules
 add_css_styles <- function(data) {
+
   styles_tbl <- dt_styles_get(data = data)
 
   styles_tbl$html_style <- vapply(styles_tbl$styles, styles_to_html, character(1))
@@ -79,6 +215,7 @@ coalesce_marks <- function(
 
 # Get the attributes for the table tag
 get_table_defs <- function(data) {
+
   boxh <- dt_boxhead_get(data = data)
 
   # Get the `table-layout` value, which is set in `_options`
@@ -224,7 +361,11 @@ create_heading_component_h <- function(data) {
         locname = "title"
       )
 
-    footnote_title_marks <- footnote_mark_to_html(mark = footnote_title_marks$fs_id_c)
+    footnote_title_marks <-
+      footnote_mark_to_html(
+        data = data,
+        mark = footnote_title_marks$fs_id_c
+      )
 
   } else {
     footnote_title_marks <- ""
@@ -255,7 +396,10 @@ create_heading_component_h <- function(data) {
       )
 
     footnote_subtitle_marks <-
-      footnote_mark_to_html(mark = footnote_subtitle_marks$fs_id_c)
+      footnote_mark_to_html(
+        data = data,
+        mark = footnote_subtitle_marks$fs_id_c
+      )
 
   } else {
     footnote_subtitle_marks <- ""
@@ -277,7 +421,7 @@ create_heading_component_h <- function(data) {
 
   title_classes <- c("gt_heading", "gt_title", "gt_font_normal")
 
-  subtitle_classes <- title_classes %>% tidy_sub("title", "subtitle")
+  subtitle_classes <- tidy_sub(title_classes, "title", "subtitle")
 
   if (!subtitle_defined) {
     title_classes <- c(title_classes, "gt_bottom_border")
@@ -287,6 +431,7 @@ create_heading_component_h <- function(data) {
 
   title_row <-
     htmltools::tags$tr(
+      class = "gt_heading",
       htmltools::tags$td(
         colspan = n_cols_total,
         class = paste(title_classes, collapse = " "),
@@ -301,6 +446,7 @@ create_heading_component_h <- function(data) {
 
     subtitle_row <-
       htmltools::tags$tr(
+        class = "gt_heading",
         htmltools::tags$td(
           colspan = n_cols_total,
           class = paste(subtitle_classes, collapse = " "),
@@ -315,8 +461,7 @@ create_heading_component_h <- function(data) {
     subtitle_row <- ""
   }
 
-  htmltools::tags$thead(
-    class = "gt_header",
+  htmltools::tagList(
     title_row,
     subtitle_row
   )
@@ -340,6 +485,7 @@ create_columns_component_h <- function(data) {
 
   stubh <- dt_stubhead_get(data = data)
   styles_tbl <- dt_styles_get(data = data)
+  body <- dt_body_get(data = data)
 
   # Get vector representation of stub layout
   stub_layout <- get_stub_layout(data = data)
@@ -354,6 +500,26 @@ create_columns_component_h <- function(data) {
   # Get the column alignments and also the alignment class names
   col_alignment <- dt_boxhead_get_vars_align_default(data = data)
 
+  # Detect any RTL script characters within the visible columns;
+  # this creates a vector the same length as `col_alignment`
+  rtl_detect <-
+    vapply(
+      dt_boxhead_get_vars_default(data = data),
+      FUN.VALUE = logical(1),
+      USE.NAMES = FALSE,
+      FUN = function(x) {
+        any(grepl(rtl_modern_unicode_charset, body[[x]]))
+      }
+    )
+
+  # For any columns containing characters from RTL scripts; we
+  # will transform a 'left' alignment to a 'right' alignment
+  for (i in seq_along(rtl_detect)) {
+    if (rtl_detect[i] && col_alignment[i] != "center") {
+      col_alignment[i] <- "right"
+    }
+  }
+
   # Get the column headings
   headings_vars <- dt_boxhead_get_vars_default(data = data)
   headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
@@ -443,7 +609,7 @@ create_columns_component_h <- function(data) {
         )
     }
 
-    table_col_headings <- htmltools::tags$tr(table_col_headings)
+    table_col_headings <- htmltools::tags$tr(class = "gt_col_headings", table_col_headings)
   }
 
   if (spanner_row_count > 0) {
@@ -605,11 +771,11 @@ create_columns_component_h <- function(data) {
     solo_headings <- headings_vars[is.na(spanner_ids[level_1_index, ])]
     remaining_headings <- headings_vars[!(headings_vars %in% solo_headings)]
 
+    remaining_headings_labels <- dt_boxhead_get(data = data)
     remaining_headings_labels <-
-      dt_boxhead_get(data = data) %>%
-      dplyr::filter(var %in% remaining_headings) %>%
-      dplyr::pull(column_label) %>%
-      unlist()
+      dplyr::filter(remaining_headings_labels, var %in% remaining_headings)
+    remaining_headings_labels <-
+      unlist(dplyr::pull(remaining_headings_labels, column_label))
 
     col_alignment <- col_alignment[-1][!(headings_vars %in% solo_headings)]
 
@@ -655,14 +821,24 @@ create_columns_component_h <- function(data) {
 
       table_col_headings <-
         htmltools::tagList(
-          htmltools::tags$tr(level_1_spanners),
-          htmltools::tags$tr(spanned_column_labels)
+          htmltools::tags$tr(
+            class = "gt_col_headings gt_spanner_row",
+            level_1_spanners
+          ),
+          htmltools::tags$tr(
+            class = "gt_col_headings",
+            spanned_column_labels
+          )
         )
 
     } else {
 
       # Create the `table_col_headings` HTML component
-      table_col_headings <- htmltools::tags$tr(level_1_spanners)
+      table_col_headings <-
+        htmltools::tags$tr(
+          class = "gt_col_headings gt_spanner_row",
+          level_1_spanners
+        )
     }
   }
 
@@ -753,7 +929,11 @@ create_columns_component_h <- function(data) {
       higher_spanner_rows <-
         htmltools::tagList(
           higher_spanner_rows,
-          htmltools::tagList(htmltools::tags$tr(level_i_spanners))
+          htmltools::tagList(
+            htmltools::tags$tr(
+              class = "gt_col_headings gt_spanner_row",
+              level_i_spanners)
+          )
         )
     }
 
@@ -764,10 +944,7 @@ create_columns_component_h <- function(data) {
       )
   }
 
-  htmltools::tags$thead(
-    class = "gt_col_headings",
-    table_col_headings
-  )
+  table_col_headings
 }
 
 #' Create the table body component (HTML)
@@ -778,7 +955,6 @@ create_body_component_h <- function(data) {
   summaries_present <- dt_summary_exists(data = data)
   list_of_summaries <- dt_summary_df_get(data = data)
   groups_rows_df <- dt_groups_rows_get(data = data)
-
   styles_tbl <- dt_styles_get(data = data)
 
   # Get effective number of columns
@@ -799,8 +975,10 @@ create_body_component_h <- function(data) {
   # Get vector representation of stub layout
   stub_layout <- get_stub_layout(data = data)
 
-  # Determine if there is a stub column in `stub_layout`
+  # Determine if there is a stub column in `stub_layout` and whether we
+  # have a two-column stub (with the group label on the left side)
   has_stub_column <- "rowname" %in% stub_layout
+  has_two_col_stub <- "group_label" %in% stub_layout
 
   # Get a matrix of all cells in the body (not including summary cells)
   cell_matrix <- get_body_component_cell_matrix(data = data)
@@ -817,29 +995,14 @@ create_body_component_h <- function(data) {
 
   alignment_classes <- paste0("gt_", col_alignment)
 
-  # Define function to get a character vector of formatted cell
-  # data (this includes the stub, if it is present)
-  output_df_row_as_vec <- function(i) {
-    cell_matrix <- cell_matrix[i, ]
-
-    if ("group_label" %in% stub_layout) {
-
-      if (!(i %in% groups_rows_df$row_start)) {
-        cell_matrix <- cell_matrix[-1]
-      }
-      if (i %in% groups_rows_df$row_start) {
-        cell_matrix[1] <- groups_rows_df$group_label[groups_rows_df$row_start == i]
-      }
-    }
-
-    cell_matrix
-  }
-
   # Replace an NA group with an empty string
   if (any(is.na(groups_rows_df$group_label))) {
+
     groups_rows_df <-
-      groups_rows_df %>%
-      dplyr::mutate(group_label = ifelse(is.na(group_label), "", group_label))
+      dplyr::mutate(
+        groups_rows_df,
+        group_label = ifelse(is.na(group_label), "", group_label)
+      )
   }
 
   # Is the stub to be striped?
@@ -886,7 +1049,7 @@ create_body_component_h <- function(data) {
         body_section <- list()
 
         group_info <-
-          groups_rows_df[groups_rows_df$row_start == i, c("group_id", "group_label")]
+          groups_rows_df[i >= groups_rows_df$row_start & i <= groups_rows_df$row_end, ]
 
         if (nrow(group_info) == 0) {
           group_info <- NULL
@@ -894,26 +1057,44 @@ create_body_component_h <- function(data) {
 
         group_id <- group_info[["group_id"]]
         group_label <- group_info[["group_label"]]
+        group_row_start <- group_info[["row_start"]]
+        group_row_end <- group_info[["row_end"]]
+        group_has_summary_rows <- group_info[["has_summary_rows"]]
+        group_summary_row_side <- group_info[["summary_row_side"]]
 
         if (!is.null(group_id)) current_group_id <<- group_id
 
-        group_heading_row_at_i <- !is.null(group_id) && !("group_label" %in% stub_layout)
+        # Is there a group heading row (dedicated row w/ group label) at `i`?
+        group_heading_row_at_i <-
+          !is.null(group_id) &&
+          !has_two_col_stub &&
+          group_row_start == i
+
+        # Is this the first row of a group?
+        group_start <- !is.null(group_info) && group_row_start == i
+
+        # Is this the first row of a group where there is a two-column stub?
+        group_start_two_col_stub <-
+          has_two_col_stub && !is.null(group_info) && group_row_start == i
 
         #
         # Create a group heading row
         #
-        if (
-          !is.null(group_id) &&
-          !("group_label" %in% stub_layout)
-        ) {
 
-          row_style <-
+        # A group heading row occurs before a formal row `i` in that it really
+        # doesn't have an index number but we do anchor it to an `i` index and
+        # place it just before row `i`
+
+        if (group_heading_row_at_i) {
+
+          row_style_row_groups_tbl <-
             dt_styles_pluck(
               styles_tbl = styles_tbl,
               locname = "row_groups",
               grpname = group_id
-            )$html_style
+            )
 
+          row_style_group_heading_row <- row_style_row_groups_tbl[["html_style"]]
 
           group_class <-
             if (group_label == "") {
@@ -928,7 +1109,7 @@ create_body_component_h <- function(data) {
               htmltools::tags$th(
                 colspan = n_cols_total,
                 class = group_class,
-                style = row_style,
+                style = row_style_group_heading_row,
                 scope = ifelse(n_cols_total > 1, "colgroup", "col"),
                 id = group_label,
                 htmltools::HTML(group_label)
@@ -938,18 +1119,56 @@ create_body_component_h <- function(data) {
           body_section <- append(body_section, list(group_heading_row))
         }
 
+        if (has_two_col_stub) {
+
+          summary_rows_group_df <-
+            list_of_summaries[["summary_df_display_list"]][[group_id]]
+
+          if (!is.null(summary_rows_group_df) && "rowname" %in% stub_layout) {
+            summary_row_count <- nrow(summary_rows_group_df)
+          } else {
+            summary_row_count <- 0L
+          }
+
+          rowspan_val <-
+            group_info$row_end - group_info$row_start + 1 + summary_row_count
+
+          row_style_row_groups_tbl <-
+            dt_styles_pluck(
+              styles_tbl = styles_tbl,
+              locname = "row_groups",
+              grpname = group_id
+            )
+
+          row_style_group_heading_row <- row_style_row_groups_tbl[["html_style"]]
+
+          group_col_td <-
+            htmltools::tags$td(
+              headers = group_id,
+              rowspan = rowspan_val,
+              class = "gt_row gt_left gt_stub_row_group",
+              style = row_style_group_heading_row,
+              id = group_id,
+              htmltools::HTML(group_label)
+            )
+        }
+
         #
         # Create a body row
         #
 
+        # This condition determines whether we are on an every 'second' body
+        # row and, if so, we use `extra_classes_2` instead of `extra_classes_1`
+        # (the former may have the `"gt_striped"` CSS class, depending on
+        # whether the option for row striping was taken)
+        extra_classes <- if (i %% 2 == 0) extra_classes_2 else extra_classes_1
+
         indentation_stub <-
           dt_stub_indentation_at_position(
             data = data,
             i = i
           )
 
-        extra_classes <- if (i %% 2 == 0) extra_classes_2 else extra_classes_1
-
         if (!is.null(indentation_stub) && indentation_stub != 0) {
 
           extra_classes[[row_label_col]] <-
@@ -973,92 +1192,181 @@ create_body_component_h <- function(data) {
             n_cols = n_data_cols
           )
 
-        if ("group_label" %in% stub_layout) {
+        #
+        # Get groupwise summary rows (for either top or bottom of group)
+        #
 
-          if (i %in% groups_rows_df$row_start) {
+        if (
+          summaries_present &&
+          !is.null(group_has_summary_rows) &&
+          group_has_summary_rows &&
+          (
+            i %in% groups_rows_df$row_start &&
+            !is.null(group_summary_row_side) &&
+            !is.na(group_summary_row_side) &&
+            group_summary_row_side == "top"
+          ) ||
+          (
+            i %in% groups_rows_df$row_end &&
+            !is.null(group_summary_row_side) &&
+            !is.na(group_summary_row_side) &&
+            group_summary_row_side == "bottom"
+          )
+        ) {
 
-            # Modify the `extra_classes` list to include a class for
-            # the row group column
-            extra_classes[[1]] <- "gt_stub_row_group"
+          summary_section <-
+            summary_rows_for_group_h(
+              data = data,
+              group_id = group_id
+            )
 
-            # Obtain a one-row table that contains the beginning and
-            # ending row index for the row group
-            row_limits <-
-              groups_rows_df %>%
-              dplyr::filter(row_start == i) %>%
-              dplyr::select(group_id, row_start, row_end)
-
-            summary_rows_group_df <-
-              list_of_summaries[["summary_df_display_list"]][[row_limits$group_id]]
-
-            if (!is.null(summary_rows_group_df) && "rowname" %in% stub_layout) {
-              summary_row_count <- nrow(summary_rows_group_df)
-            } else {
-              summary_row_count <- 0L
-            }
-
-            # Modify the `row_span_vals` list such that the first
-            # element (the row group column) contains the number of rows to span
-            row_span_vals[[1]] <-
-              row_limits$row_end - row_limits$row_start + 1 + summary_row_count
-
-            # Process row group styles if there is an indication that some
-            # are present
-            row_group_style <-
-              dt_styles_pluck(
-                styles_tbl = styles_tbl,
-                locname = "row_groups",
-                grpname = group_id
-              )$html_style
-
-            # Add style of row group cell to vector
-            row_styles <- c(list(row_group_style), row_styles)
-
-          } else {
-
-            # Remove first element of `alignment_classes` vector
-            alignment_classes <- alignment_classes[-1]
-            row_span_vals[[1]] <- NULL
-            extra_classes[[1]] <- NULL
-          }
+        } else {
+          summary_section <- NULL
         }
 
-        row_df <- output_df_row_as_vec(i = i)
+        # Handle the layout case where there is a 'two-column stub', which
+        # is the row group label occupying a separate column to the LHS of
+        # the row labels (this column needs to have a correct rowspan value
+        # on the group)
+        #
+        # The first subcase of this is where `i` is the first row of
+        # this grouping of rows
+        if (has_two_col_stub && i %in% groups_rows_df$row_start) {
 
-        # Situation where we have two columns in the stub and the row isn't the
-        # first (the `row_df` vector will have one less element)
+          # Modify the `extra_classes` list to include a class for
+          # the row group column
+          extra_classes[[1]] <- "gt_stub_row_group"
+
+          # Obtain a one-row table that contains the beginning and
+          # ending row index for the row group
+          row_limits <-
+            dplyr::select(
+              dplyr::filter(
+                groups_rows_df, row_start == i
+              ),
+              group_id, row_start, row_end
+            )
+
+          summary_rows_group_df <-
+            list_of_summaries[["summary_df_display_list"]][[row_limits$group_id]]
+
+          if (!is.null(summary_rows_group_df) && "rowname" %in% stub_layout) {
+            summary_row_count <- nrow(summary_rows_group_df)
+          } else {
+            summary_row_count <- 0L
+          }
+
+          # If the summary rows are to be located at the bottom of the group
+          # modify the `row_span_vals` list such that the first element
+          # contains the number of rows to span
+          # TODO: replace with condition for summary rows at bottom
+
+          if (!(!is.null(summary_section) && group_summary_row_side == "top")) {
+            row_span_vals[[1]] <-
+              row_limits$row_end - row_limits$row_start + 1 + summary_row_count
+          }
+
+          # Process row group styles if there is an indication that any
+          # are present
+          row_style_row_groups_tbl <-
+            dt_styles_pluck(
+              styles_tbl = styles_tbl,
+              locname = "row_groups",
+              grpname = group_id
+            )
+
+          row_style_group_heading_row <- row_style_row_groups_tbl[["html_style"]]
+
+          # Add style of row group cell to vector
+          row_styles <- c(list(row_style_group_heading_row), row_styles)
+        }
+
+        # The second subcase of this is where `i` is *not* the first row
+        # of this grouping of rows and we'd want the leftmost column with
+        # the group label to not have a rowspan attr or any special classes
+        if (has_two_col_stub && !(i %in% groups_rows_df$row_start)) {
+
+          # Remove first element of `alignment_classes` vector
+          alignment_classes <- alignment_classes[-1]
+          row_span_vals[[1]] <- NULL
+          extra_classes[[1]] <- NULL
+        }
+
+        row_df <-
+          output_df_row_as_vec(
+            i = i,
+            cell_matrix = cell_matrix,
+            groups_rows_df = groups_rows_df,
+            has_two_col_stub = has_two_col_stub
+          )
+
+        # Situation where we have two columns in the stub and the row label
+        # isn't the first (the `row_df` vector will have one less element)
         if (length(col_names_id) > length(row_df)) {
-          col_names_id_i <- col_names_id[-(length(col_names_id) - length(row_df))]
+          col_id_i <- col_names_id[-(length(col_names_id) - length(row_df))]
         } else {
-          col_names_id_i <- col_names_id
+          col_id_i <- col_names_id
         }
 
         stub_width <- length(stub_layout)
 
         if (stub_width == 0) {
-          row_id_i <- rep("", length(col_names_id_i))
+          row_id_i <- rep("", length(col_id_i))
         } else if (stub_width == 1) {
-          row_id_i <- rep(paste0(col_names_id_i[1], "_", i), length(col_names_id_i))
+          row_id_i <- rep(paste0(col_id_i[1], "_", i), length(col_id_i))
         } else if (stub_width == 2) {
-          row_id_i <- rep(paste0(col_names_id_i[2], "_", i), length(col_names_id_i))
+          row_id_i <- rep(paste0(col_id_i[2], "_", i), length(col_id_i))
+        }
+
+        # In the situation where there is:
+        # (1) a group summary to be situated at the top of the group, and,
+        # (2) a two-column stub
+        # we have to excise the redundant group label
+        if (
+          summaries_present &&
+          !is.null(group_has_summary_rows) &&
+          group_has_summary_rows &&
+          group_start_two_col_stub &&
+          !is.null(group_summary_row_side) &&
+          !is.na(group_summary_row_side) &&
+          group_summary_row_side == "top"
+        ) {
+
+          row_df <- row_df[-1]
+          col_id_i <- col_id_i[-1]
+          row_id_i <- row_id_i[-1]
+          row_span_vals <- row_span_vals[-1]
+          alignment_classes <- alignment_classes[-1]
+          extra_classes <- extra_classes[-1]
+          row_styles <- row_styles[-1]
         }
 
         body_row <-
           htmltools::tags$tr(
-            class = if (!is.null(group_info)) "gt_row_group_first",
+            class = if (group_start) "gt_row_group_first",
             htmltools::HTML(
               paste0(
                 mapply(
                   SIMPLIFY = FALSE,
                   USE.NAMES = FALSE,
                   row_df,
-                  col_names_id_i,
+                  col_id_i,
                   row_id_i,
                   row_span_vals,
                   alignment_classes,
                   extra_classes,
                   row_styles,
                   FUN = function(x, col_id, row_id, row_span, alignment_class, extra_class, cell_style) {
+
+                    # If any characters come from a RTL script, ensure that a
+                    # left alignment is transformed to a right alignment
+                    if (grepl(rtl_modern_unicode_charset, x)) {
+                      if (alignment_class != "gt_center") {
+                        alignment_class <- "gt_right"
+                      }
+                      x <- paste0("<p dir=\"rtl\">", x, "</p>")
+                    }
+
                     sprintf(
                       "<%s %sclass=\"%s\"%s>%s</%s>",
                       if ("gt_stub" %in% extra_class) {
@@ -1075,8 +1383,10 @@ create_body_component_h <- function(data) {
                         paste0(
                           "td ",
                           "headers=\"",
-                          gsub("(^[[:space:]]*)|([[:space:]]*$)", "",
-                               paste(current_group_id, row_id, col_id)),
+                          gsub(
+                            "(^[[:space:]]*)|([[:space:]]*$)", "",
+                            paste(current_group_id, row_id, col_id)
+                          ),
                           "\""
                         )
                       },
@@ -1120,27 +1430,20 @@ create_body_component_h <- function(data) {
             )
           )
 
+
+        if (!is.null(summary_section) && group_summary_row_side == "top") {
+
+          if (has_two_col_stub) {
+
+            summary_section[[1]] <-
+              htmltools::HTML(gsub("^<tr>", paste0("<tr>", group_col_td), as.character(summary_section[[1]])))
+          }
+          body_section <- append(body_section, summary_section)
+        }
+
         body_section <- append(body_section, list(body_row))
 
-        #
-        # Add groupwise summary rows
-        #
-
-        if (summaries_present &&
-          i %in% groups_rows_df$row_end) {
-          group_id <-
-            groups_rows_df[
-              stats::na.omit(groups_rows_df$row_end == i),
-              "group_id",
-              drop = TRUE
-            ]
-
-          summary_section <-
-            summary_row_tags_i(
-              data = data,
-              group_id = group_id
-            )
-
+        if (!is.null(summary_section) && group_summary_row_side == "bottom") {
           body_section <- append(body_section, summary_section)
         }
 
@@ -1159,13 +1462,20 @@ create_body_component_h <- function(data) {
     grand_summary_col %in% names(list_of_summaries$summary_df_display_list)
   ) {
 
+    side <- summary_row_side(data = data, group_id = grand_summary_col)
+
     grand_summary_section <-
-      summary_row_tags_i(
+      summary_rows_for_group_h(
         data = data,
-        group_id = grand_summary_col
+        group_id = grand_summary_col,
+        side_grand_summary = side
       )
 
-    body_rows <- c(body_rows, grand_summary_section)
+    if (side == "top") {
+      body_rows <- c(grand_summary_section, body_rows)
+    } else {
+      body_rows <- c(body_rows, grand_summary_section)
+    }
   }
 
   htmltools::tags$tbody(
@@ -1174,6 +1484,30 @@ create_body_component_h <- function(data) {
   )
 }
 
+# Define function to get a character vector of formatted cell
+# data (this includes the stub, if it is present)
+output_df_row_as_vec <- function(
+    i,
+    cell_matrix,
+    groups_rows_df,
+    has_two_col_stub
+) {
+
+  cell_matrix <- cell_matrix[i, ]
+
+  if (has_two_col_stub) {
+
+    if (!(i %in% groups_rows_df$row_start)) {
+      cell_matrix <- cell_matrix[-1]
+    }
+    if (i %in% groups_rows_df$row_start) {
+      cell_matrix[1] <- groups_rows_df$group_label[groups_rows_df$row_start == i]
+    }
+  }
+
+  cell_matrix
+}
+
 #' Create the table source note component (HTML)
 #'
 #' @noRd
@@ -1273,13 +1607,11 @@ create_footnotes_component_h <- function(data) {
 
   styles_tbl <- dt_styles_get(data = data)
 
-  # Get effective number of columns
+  # Get the effective number of columns
   n_cols_total <- get_effective_number_of_columns(data = data)
 
-  footnotes_tbl <-
-    footnotes_tbl %>%
-    dplyr::select(fs_id, footnotes) %>%
-    dplyr::distinct()
+  # Get the distinct set of `fs_id` & `footnotes` values in the `footnotes_tbl`
+  footnotes_tbl <- dplyr::distinct(dplyr::select(footnotes_tbl, fs_id, footnotes))
 
   # Get the style attrs for the footnotes
   if ("footnotes" %in% styles_tbl$locname) {
@@ -1321,7 +1653,11 @@ create_footnotes_component_h <- function(data) {
             htmltools::tagList(
               htmltools::HTML(
                 paste0(
-                  footnote_mark_to_html(x),
+                  footnote_mark_to_html(
+                    data = data,
+                    mark = x,
+                    location = "ftr"
+                  ),
                   " ",
                   process_text(footnote_text, context = "html")
                 ),
@@ -1380,53 +1716,11 @@ create_footnotes_component_h <- function(data) {
   )
 }
 
-# Get a matrix of all body cells
-get_body_component_cell_matrix <- function(data) {
-
-  body <- dt_body_get(data = data)
-  stub_layout <- get_stub_layout(data = data)
-  default_vars <- dt_boxhead_get_vars_default(data = data)
-
-  body_matrix <- unname(as.matrix(body[, default_vars]))
-
-  if (length(stub_layout) == 0) {
-    return(body_matrix)
-  }
-
-  if ("rowname" %in% stub_layout) {
-
-    body_matrix <-
-      cbind(
-        unname(as.matrix(body[, dt_boxhead_get_var_stub(data = data)])),
-        body_matrix
-      )
-  }
-
-  if ("group_label" %in% stub_layout) {
-
-    groups_rows_df <-
-      dt_groups_rows_get(data = data) %>%
-      dplyr::select(group_id, group_label, row_start)
-
-    group_label_matrix <-
-      dt_stub_df_get(data = data) %>%
-      dplyr::select(-row_id, -group_label) %>%
-      dplyr::inner_join(groups_rows_df, by = "group_id") %>%
-      dplyr::mutate(
-        row = dplyr::row_number(),
-        built = dplyr::if_else(row_start != row, "", built_group_label)
-      ) %>%
-      dplyr::select(built) %>%
-      as.matrix() %>%
-      unname()
-
-    body_matrix <- cbind(group_label_matrix, body_matrix)
-  }
-
-  body_matrix
-}
-
-summary_row_tags_i <- function(data, group_id) {
+summary_rows_for_group_h <- function(
+    data,
+    group_id,
+    side_grand_summary = "bottom"
+) {
 
   # Check that `group_id` isn't NULL and that length is exactly 1
   if (is.null(group_id) || length(group_id) != 1) {
@@ -1518,6 +1812,11 @@ summary_row_tags_i <- function(data, group_id) {
       summary_row_class <- "gt_grand_summary_row"
       first_row_class <- "gt_first_grand_summary_row"
 
+      if (side_grand_summary == "top") {
+        first_row_class <- "gt_grand_summary_row"
+        last_row_class <- "gt_last_grand_summary_row_top"
+      }
+
     } else {
 
       styles_resolved_row <-
@@ -1552,7 +1851,7 @@ summary_row_tags_i <- function(data, group_id) {
             mapply(
               SIMPLIFY = FALSE,
               USE.NAMES = FALSE,
-              unname(unlist(summary_df[j, ])),
+              summary_df[j, ],
               col_span_vals,
               alignment_classes,
               extra_classes,
@@ -1569,6 +1868,12 @@ summary_row_tags_i <- function(data, group_id) {
                   extra_class <- c(extra_class, last_row_class)
                 }
 
+                x <- x[[1]]
+
+                if (inherits(x, "from_markdown")) {
+                  x <- process_text(x, context = "html")
+                }
+
                 sprintf(
                   "<%s %sclass=\"%s\"%s>%s</%s>",
                   if ("gt_stub" %in% extra_class) {
