@@ -1,4 +1,4 @@
-test_that("the the `pct()` helper function works correctly", {
+test_that("The `pct()` helper function works correctly", {
 
   # Create a CSS percentage value string
   percentage <- pct(x = 50)
@@ -11,7 +11,7 @@ test_that("the the `pct()` helper function works correctly", {
     pct(x = "50"))
 })
 
-test_that("the the `px()` helper function works correctly", {
+test_that("The `px()` helper function works correctly", {
 
   # Create a CSS pixel value string
   pixels <- px(x = 50)
@@ -23,3 +23,15 @@ test_that("the the `px()` helper function works correctly", {
   expect_error(
     px(x = "50"))
 })
+
+test_that("The `cells_group()` emits a warning but works correctly", {
+
+  # Expect a warning from the deprecated `cells_group()` function; it
+  # still does return a useful list object
+  expect_warning(
+    out <- cells_group()
+  )
+
+  # Expect that the output from `cells_group()` is a list
+  expect_type(out, "list")
+})
