@@ -1,4 +1,4 @@
-test_that("the `fmt_date()` function works correctly", {
+test_that("The `fmt_date()` function works correctly", {
 
   # Create an input tibble frame with a single column
   # that contains dates as character values
@@ -269,7 +269,7 @@ test_that("the `fmt_date()` function works correctly", {
   )
 })
 
-test_that("the `fmt_time()` function works correctly", {
+test_that("The `fmt_time()` function works correctly", {
 
   # Create an input tibble frame with a single column
   # that contains times as character values
@@ -321,7 +321,7 @@ test_that("the `fmt_time()` function works correctly", {
   )
 })
 
-test_that("the `fmt_datetime()` function works correctly", {
+test_that("The `fmt_datetime()` function works correctly", {
 
   # Create an input tibble frame with a single column
   # that contains date-times as character values
